@@ -1841,6 +1841,27 @@ class Blockchain(object):
             # in while the caller is working with it. It will never be very big.
             return set(requests)
         
+    def get_state_hash(self):
+        """
+        Return the hash of the current State.
+        
+        """
+        
+        with self.lock:
+            
+            return self.state.get_hash()
+    
+    def get_state_component(self, component_hash):
+        """
+        Return the bytrestring for the component with the given hash, or None if
+        we don't have one.
+        
+        """
+        
+        with self.lock:
+            
+            return self.state.get_component(component_hash)
+    
     def add_state_component(self, component_bytestring):
         """
         Give a StateComponent bytestring to the Blockchain in order to try and
