@@ -362,7 +362,7 @@ class BlockchainProtocol(LineReceiver):
                 
                 # Go get it
                 state_component = \
-                    self.factory.peer.blockchain.state.get_component(state_hash)
+                    self.factory.peer.blockchain.get_state_component(state_hash)
                     
                 if state_component is None:
                     # Complain we don't have that. They need to start over from
@@ -370,7 +370,7 @@ class BlockchainProtocol(LineReceiver):
                     logging.warning("Peer requested nonexistent StateComponent "
                         "{} vs. root hash {}".format(parts[1], 
                         bytes2string(
-                        self.factory.peer.blockchain.state.get_hash())))
+                        self.factory.peer.blockchain.get_state_hash())))
                     self.send_message(["NOSTATE", bytes2string(state_hash)])
                 else:
                 
