@@ -304,6 +304,8 @@ class Peer(object):
                 # state) take.
                 pybc.science.log_event("blockchain_usage", 
                     self.blockchain.get_disk_usage())
+                pybc.science.log_filesize("blockchain_file_usage", 
+                    self.blockchain.store_filename)
             
             # Request whatever state components we need, egardless if whether we
             # recently requested them, in case our download got stalled
