@@ -11,6 +11,5 @@ from pybc.ServerFactory import *
 from pybc.State import *
 from pybc.TransactionalBlockchain import *
 
-# Define all our submodules for importing. Currently just a submodule for
-# Bitcoin-alikes. Don't make the testing scripts under testing/ importable.
-__all__ = ["coin", "util", "transactions"]
+# Define all our submodules for importing.
+__all__ = ["coin", "util", "transactions", "science"]
